@@ -102,16 +102,20 @@ def test_zeroshotclassifier_french_segments(expected_fr):
 
 @pytest.mark.skip(reason="Not a test")
 def test_zeroshotclassifier_HM(expected_fr):
+    from sklearn.metrics import classification_report
     testdir = Path(__file__).parent
     source = Path(testdir, 'data/kairntech_exemple.json')
     with source.open("r") as fin:
         docs = json.load(fin)
     docs = [Document(**doc) for doc in docs]
+    y_true = [doc.metadata['Thème'] for doc in docs]
     annotator = ZeroShotClassifierAnnotator()
     parameters = ZeroShotClassifierParameters(model=TrfModel.camembert_base_xnli,
                                               candidate_labels="Apprentissage et éducation,Arts et culture,Complexité et incertitude,Innovation et créativité,La générosité,La mort,La motivation,L'amour,La technologie et ses usages,La violence,Les émotions et notre cognition,Les intersections,Les mouvements migratoires,Les réseaux sociaux,Le temps,L'inattendu dans nos interactions,L'individu et l'appartenance à un collectif,Ma théorie,Mondialisation et circuits courts,Nature et environnement,Résilience et adaptabilité,Santé et bien-être,Surconsommation et ressources naturelles,Travail et modes de vie,Urbanisme et ruralité,Valeur et perception,Vie collective (bien commun - démocratie - solidarité)",
-                                              multi_label=True, multi_label_threshold=0.2)
+                                              multi_label=False, multi_label_threshold=0.2)
     docs: List[Document] = annotator.annotate(docs, parameters)
+    y_pred = [doc.categories[0].label for doc in docs]
+    print(classification_report(y_true, y_pred))
     dl = DocumentList(__root__=docs)
     result = Path(testdir, 'data/kairntech_exemple_zeroed.json')
     with result.open("w") as fout:
